@@ -1,6 +1,5 @@
 package App::Alice::CommandDispatch;
 
-use Encode;
 use Any::Moose;
   
 has 'handlers' => (
@@ -71,13 +70,11 @@ sub names {
 
 sub whois {
   my ($self, $window, $nick) = @_;
-  $nick = decode("utf8", $nick, Encode::FB_QUIET);
   $self->app->send([$window->format_announcement($window->irc->whois_table($nick))]);
 }
 
 sub query {
   my ($self, $window, $nick) = @_;
-  $nick = decode("utf8", $nick, Encode::FB_QUIET);
   my $new_window = $self->app->find_or_create_window($nick, $window->irc);
   $self->app->send([$new_window->join_action]);
 }
@@ -113,7 +110,6 @@ sub nick {
 
 sub create {
   my ($self, $window, $name) = @_;
-  $name = decode("utf8", $name, Encode::FB_QUIET);
   my $new_window = $self->app->find_or_create_window($name, $window->irc);
   $self->app->send([$new_window->join_action]);
 }
@@ -145,7 +141,6 @@ sub me {
 
 sub quote {
   my ($self, $window, $commands) = @_;
-  $commands = decode("utf8", $commands, Encode::FB_QUIET);
   $window->irc->cl->send_raw(split /\s+/, $commands);
 }
 
@@ -194,7 +189,6 @@ sub notfound {
 sub _say {
   my ($self, $window, $msg) = @_;
   $self->app->send([$window->format_message($window->nick, $msg)]);
-  $msg = decode("utf8", $msg, Encode::FB_QUIET);
   $window->irc->cl->send_srv(PRIVMSG => $window->title, $msg);
 }
 
